# OE1100
##############################################################################################################################
# Script for OE Sales Order Entry.
# Adds the two additional fields to the O/E order entry detail grid.
# - Standard Cost (from the OEORDD record)
# - Recent Standard Cost (from the ICILOC record for the item and location)
# You can drag & drop them to the left hand side of the grid if required.
##############################################################################################################################
# Copyright 2018 Orchid Systems
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an "as is" basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
##############################################################################################################################

from accpac import *

vICILOC = None

def main(args):
	MyUI()

class MyUI(UI):
	def __init__(self):
		UI.__init__(self)
		self.createScreen()

	def createScreen(self):
		grid = self.getHostControl("avlOEORDDdetail1")
		self.grid = grid
		
		col = UIGridColumn()
		col.caption = "Standard Cost"
		col.hasFinder = False
		col.isEditable = False
		grid.addColumn(col, "STDCOST")
		
		col = UIGridColumn()
		col.caption = "Current Standard Cost"
		col.hasFinder = False
		col.isEditable = False
		grid.addColumn(col, "ITEM")

		grid.setOnGetText(self.onGridGetText)
		
		self.dsDetail = self.openDataSource("adsOEORDD")
		grid.refreshData()
		self.show()

	def onGridGetText(self, e):
		global vICILOC
		
		if vICILOC == None:
			vICILOC = openView("IC0290")

		if e.caption == "Standard Cost":
			e.value = "{:.3f}".format(float(self.dsDetail.get("STDCOST")))
			
		if e.caption == "Current Standard Cost":
			# set default value:
			e.value = "0.000"
			# if it's an item line, get the standard cost from ICILOC.
			if int(self.dsDetail.get("LINETYPE")) == 1:
				unfmtitem = self.dsDetail.get("UNFMTITEM").strip()
				loc = self.dsDetail.get("LOCATION").strip()
				if (unfmtitem != "") and (loc != ""):
					vICILOC.recordClear()
					vICILOC.put("ITEMNO", unfmtitem)
					vICILOC.put("LOCATION", loc)
					if vICILOC.read() == 0:
						stdcost = "{:.3f}".format(float(vICILOC.get("STDCOST")))
						e.value = stdcost
			